
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacSHA384__
#define __gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacSHA384__

#pragma interface

#include <gnu/javax/crypto/jce/PBKDF2SecretKeyFactory.h>
extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace jce
        {
            class PBKDF2SecretKeyFactory$HMacSHA384;
        }
      }
    }
  }
}

class gnu::javax::crypto::jce::PBKDF2SecretKeyFactory$HMacSHA384 : public ::gnu::javax::crypto::jce::PBKDF2SecretKeyFactory
{

public:
  PBKDF2SecretKeyFactory$HMacSHA384();
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_crypto_jce_PBKDF2SecretKeyFactory$HMacSHA384__
