
// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_crypto_cipher_CipherFactory__
#define __gnu_javax_crypto_cipher_CipherFactory__

#pragma interface

#include <java/lang/Object.h>
extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace crypto
      {
        namespace cipher
        {
            class CipherFactory;
            class IBlockCipher;
        }
      }
    }
  }
}

class gnu::javax::crypto::cipher::CipherFactory : public ::java::lang::Object
{

  CipherFactory();
public:
  static ::gnu::javax::crypto::cipher::IBlockCipher * getInstance(::java::lang::String *);
  static ::java::util::Set * getNames();
  static ::java::lang::Class class$;
};

#endif // __gnu_javax_crypto_cipher_CipherFactory__
